Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsCharacterComplete ¶ added in v1.10.0
Types ¶
type Summary ¶
type Summary struct {
//version stuff
V2 bool `json:"v2"`
Version string `json:"version"`
BuildDate string `json:"build_date"`
IsDamageMode bool `json:"is_damage_mode"`
ActiveChar string `json:"active_char"`
CharNames []string `json:"char_names"`
DamageByChar []map[string]agg.FloatStat `json:"damage_by_char"`
DamageInstancesByChar []map[string]agg.IntStat `json:"damage_instances_by_char"`
DamageByCharByTargets []map[int]agg.FloatStat `json:"damage_by_char_by_targets"`
CharActiveTime []agg.IntStat `json:"char_active_time"`
AbilUsageCountByChar []map[string]agg.IntStat `json:"abil_usage_count_by_char"`
ParticleCount map[string]agg.FloatStat `json:"particle_count"`
ReactionsTriggered map[string]agg.IntStat `json:"reactions_triggered"`
ElementUptime []map[string]agg.IntStat `json:"ele_uptime"`
RequiredER []float64 `json:"required_er"`
IncompleteChars []string `json:"incomplete_chars"`
Duration agg.FloatStat `json:"sim_duration"`
//final result
Damage agg.FloatStat `json:"damage"`
DPS agg.FloatStat `json:"dps"`
DPSByTarget map[int]agg.FloatStat `json:"dps_by_target"`
DamageOverTime map[string]agg.FloatStat `json:"damage_over_time"`
Iterations int `json:"iter"`
Runtime float64 `json:"runtime"`
//other info
NumTargets int `json:"num_targets"` //TODO: to deprecate this
CharDetails []simulation.CharacterDetail `json:"char_details"`
TargetDetails []enemy.EnemyProfile `json:"target_details"`
//for tracking min/max run
MinSeed int64 `json:"-"`
MaxSeed int64 `json:"-"`
//put these last so result is kinda readable by human
Config string `json:"config_file"`
Text string `json:"text"`
Debug []map[string]interface{} `json:"debug"`
DebugMinDPSRun []map[string]interface{} `json:"debug_min_dps_run,omitempty"`
DebugMaxDPSRun []map[string]interface{} `json:"debug_max_dps_run,omitempty"`
}
func (*Summary) Map ¶ added in v1.2.2
func (r *Summary) Map(cfg *ast.ActionList, result *agg.Result)
TODO: very temporary mess to have the new aggregate system connect to the legacy summary
func (*Summary) PrettyPrint ¶
Click to show internal directories.
Click to hide internal directories.